Tagy
====
[![Build Status](https://travis-ci.org/melnikov-ivan/tagy.svg?branch=master)](https://travis-ci.org/melnikov-ivan/tagy)

Python static site generator

Features
--------

* Jinja
* Custom params
* Custom indexes (tag, category, etc)
* Custom page structure
* Useful Jinja filters: thumbnails 

Installation
------------

* With pip ```pip install tagy```
* With EasyInstall ```easy_install tagy```
* From source 
```
git clone https://github.com/melnikov-ivan/tagy.git
cd tagy
python setup.py install
```

Development
-----------
```
cd tests/
python -m unittest tagy_test
```

Sites powered by Tagy
---------------------
 * http://imelnikov.ru

